#!/bin/bash
#
# uc4_env.sh
# Set up environment variables for UC4 (Automation Engine)
#
# Author
# Michael A. Lowry <michael_lowry@swissre.com> <michael.lowry@gmail.com>
#
# Version	Date		Description
# 1.0		2020.08.11	Initial version
# 1.1		2020.08.11	Updated and expanded AE log search functions
# 1.2		2022.08.26	Added variables for agent service managers
# 1.3		2022.09.20	Changed search functions to egrep

# Set shell options
shopt -s extglob # Extended globbing enables lists like '@(A|B|C)'

# Global variables
if [[ "${SERVER_FUNCTION}" == "UC4_AE" ]]; then
	AE_ENV="$SERVER_ENVIRONMENT"
	AE_NODE="$SERVER_NODE"
fi
SMgr_Host=${HOSTNAME}
AE_HOME="/opt/uc4/server"
AE_LOG_HOME="/var/uc4/server"
AE_SMGR_HOME="/opt/uc4/servicemanager-server"
SMGR_HOME_AE="/opt/uc4/servicemanager-server"
SMGR_HOME_UNIX="/opt/uc4/servicemanager"
SMGR_HOME_SQL="/opt/uc4/servicemanager-sql"
SMGR_HOME_REST="/opt/uc4/servicemanager-ra-rest"
SMGR_HOME_WEBS="/opt/uc4/servicemanager-ra-webs"
SMGR_HOME_JMS="/opt/uc4/servicemanager-ra-jms"
SMGR_HOME_BOBJ="/opt/uc4/servicemanager-ra-bobj"
SMGR_HOME_PCE="/opt/uc4/sm-ra-pce"
VERBOSE_MODE="false"
UC4_SHARE="/opt/uc4/share"
UC4_SCRIPTS="${UC4_SHARE}/scripts"
LD_LIBRARY_PATH="${AE_SMGR_HOME}:${LD_LIBRARY_PATH}"
CLASSPATH_ORIG=$CLASSPATH
export JAVA_HOME="/opt/uc4/java/default"
export JAVA_ROOT="/opt/uc4/java/default"
export JAVA_BINDIR="/opt/uc4/java/default/bin"
export JRE_HOME="/opt/uc4/java/default"
export ORACLE_HOME="/opt/oclient/default"
export PATH=$JAVA_HOME/bin:$ORACLE_HOME/bin:$PATH
export LD_LIBRARY_PATH=$ORACLE_HOME/lib:$AE_HOME:$AE_SMGR_HOME:$LD_LIBRARY_PATH
export CLASSPATH=$ORACLE_HOME/jdbc/lib/ojdbc10.jar:$AE_HOME:$AE_HOME/lib:$CLASSPATH_ORIG
export KRB5_CONFIG=$JAVA_HOME/lib/krb5.conf
#export JAVA_TOOL_OPTIONS="-Dsun.security.krb5.debug=true -Djavax.security.auth.login.name=UC4_${AE_ENV}/${SERVER}"
export JAVA_TOOL_OPTIONS="-Dsun.security.krb5.debug=true"
export HTTP_PROXY="http://gate-zrh-os.swissre.com:8080/"
export HTTPS_PROXY="http://gate-zrh-os.swissre.com:8080/"
export http_proxy="http://gate-zrh-os.swissre.com:8080/"
export https_proxy="http://gate-zrh-os.swissre.com:8080/"

export CALIB="/opt/uc4/lib"
export CABIN="/opt/uc4/bin"
export CASHCOMP="/opt/uc4"

# For TIME_WAIT/CLOSE_WAIT check:
max_retries=12
retry_delay=10

# Aliases & functions useful to UC4/AE administrators
alias util="cd ${AE_HOME}/../utilities"
alias smgr="cd ${AE_SMGR_HOME}"
alias smgrl="cd /var/uc4/servicemanager-server"
alias server="cd i${AE_HOME}"
alias serverl="cd /var/uc4/server"
alias trc="cd /net/hnfsuc4logs/appshare/uc4logs/traces_${SERVER_ENVIRONMENT_LC}"
alias share="cd ${UC4_SHARE}"
alias scr="cd ${UC4_SCRIPTS}"
alias cfg="cd ${UC4_SHARE}/Config_Files"
alias misc="cd ${UC4_SHARE}/AE_Misc_Files"
alias templ="cd ${UC4_SHARE}/AE_Templates"
alias opts="cd ${UC4_SHARE}/AE_Env_Opts"
alias dl="cd ${UC4_SHARE}/Automic_Downloads"
alias cdr="cd \$( ls -tr | tail -1 )"
alias lt="ls -ltr"
alias tmux='LD_LIBRARY_PATH=$LD_LIBRARY_PATH:~/tmux/libevent/lib/lib/ ~/tmux/bin/tmux'

set_wpl () { wpl=$( grep -L U02000091 ${AE_LOG_HOME}/WPsrv_${AE_ENV}_log_0??_00.txt ${AE_LOG_HOME}/WPsrv_${AE_ENV}_log_$(date +%Y%m%d)* 2>/dev/null ); }; set_wpl
set_cpl () { cpl=$( grep -L U02000091 ${AE_LOG_HOME}/CPsrv_${AE_ENV}_log_0??_00.txt ${AE_LOG_HOME}/CPsrv_${AE_ENV}_log_$(date +%Y%m%d)* 2>/dev/null ); }; set_cpl
set_jwpl () { jwpl=$( grep -l U02000091 ${AE_LOG_HOME}/WPsrv_${AE_ENV}_log_0??_00.txt ${AE_LOG_HOME}/WPsrv_${AE_ENV}_log_$(date +%Y%m%d)* 2>/dev/null ); }; set_jwpl
set_jcpl () { jcpl=$( grep -l U02000091 ${AE_LOG_HOME}/CPsrv_${AE_ENV}_log_0??_00.txt ${AE_LOG_HOME}/CPsrv_${AE_ENV}_log_$(date +%Y%m%d)* 2>/dev/null ); }; set_jcpl

# Search WP/CP logs in the current hour
swpl () { local search_term=$1; set_wpl; for file in ${wpl}; do grep "$(date +%Y%m%d/%H)" "${file}" | egrep "$search_term"; done }
scpl () { local search_term=$1; set_cpl; for file in ${cpl}; do grep "$(date +%Y%m%d/%H)" "${file}" | egrep "$search_term"; done }
# Search JWP/JCP logs in the current hour
sjwpl () { local search_term=$1; set_jwpl; for file in ${jwpl}; do grep "$(date +%Y%m%d/%H)" "${file}" | egrep "$search_term"; done }
sjcpl () { local search_term=$1; set_jcpl; for file in ${jcpl}; do grep "$(date +%Y%m%d/%H)" "${file}" | egrep "$search_term"; done }
# Count number of hits in WP/CP logs in the current hour
cwpl () { local search_term=$1; set_wpl; { for file in ${wpl}; do printf "${file}: "; grep "$(date +%Y%m%d/%H)" "${file}" | egrep "$search_term" | wc -l; done } | sort; }
ccpl () { local search_term=$1; set_cpl; { for file in ${cpl}; do printf "${file}: "; grep "$(date +%Y%m%d/%H)" "${file}" | egrep "$search_term" | wc -l; done } | sort; }
# Count number of hits in  JWP/JCP logs in the current hour
cjwpl () { local search_term=$1; set_jwpl; { for file in ${jwpl}; do printf "${file}: "; grep "$(date +%Y%m%d/%H)" "${file}" | egrep "$search_term" | wc -l; done } | sort; }
cjcpl () { local search_term=$1; set_jcpl; { for file in ${jcpl}; do printf "${file}: "; grep "$(date +%Y%m%d/%H)" "${file}" | egrep "$search_term" | wc -l; done } | sort; }
